==> jc-1.4.0.tar.gz: javax/security/auth/login/LoginContext.h <==
// public class javax.security.auth.login.LoginContext

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6fe934cf02ea1e8d javax_security_auth_login_LoginContext

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_login_LoginContext_H_
#define _JC_javax_security_auth_login_LoginContext_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_javax_security_auth_Subject$object;
struct _jc_javax_security_auth_callback_CallbackHandler$object;
struct _jc_javax_security_auth_login_AppConfigurationEntry$object;
struct _jc_javax_security_auth_spi_LoginModule$object;

// Typedefs
typedef struct _jc_javax_security_auth_login_LoginContext$sub_refs	_jc_javax_security_auth_login_LoginContext$sub_refs;
typedef struct _jc_javax_security_auth_login_LoginContext$sub_nonrefs	_jc_javax_security_auth_login_LoginContext$sub_nonrefs;
typedef struct _jc_javax_security_auth_login_LoginContext$refs	_jc_javax_security_auth_login_LoginContext$refs;
typedef struct _jc_javax_security_auth_login_LoginContext$nonrefs	_jc_javax_security_auth_login_LoginContext$nonrefs;
typedef struct _jc_javax_security_auth_login_LoginContext$object	_jc_javax_security_auth_login_LoginContext$object;

typedef struct _jc_javax_security_auth_login_LoginContext$fields_struct	_jc_javax_security_auth_login_LoginContext$fields_struct;
typedef const struct _jc_javax_security_auth_login_LoginContext$vmethods	_jc_javax_security_auth_login_LoginContext$vmethods;
typedef const struct _jc_javax_security_auth_login_LoginContext$vtable	_jc_javax_security_auth_login_LoginContext$vtable;
typedef const struct _jc_javax_security_auth_login_LoginContext$vtype	_jc_javax_security_auth_login_LoginContext$vtype;

// Class fields structure
struct _jc_javax_security_auth_login_LoginContext$fields_struct {
	struct _jc_java_lang_String$object	*OTHER;
};
extern _jc_javax_security_auth_login_LoginContext$fields_struct _jc_javax_security_auth_login_LoginContext$class_fields;

// Constructors
extern void _jc_javax_security_auth_login_LoginContext$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_security_auth_login_LoginContext$method$_init$95c94ca4add8ad7a(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *, struct _jc_java_lang_String$object *, struct _jc_javax_security_auth_Subject$object *);
extern void _jc_javax_security_auth_login_LoginContext$method$_init$3e91c4d32da7a4da(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *, struct _jc_java_lang_String$object *, struct _jc_javax_security_auth_Subject$object *, struct _jc_object *);
extern void _jc_javax_security_auth_login_LoginContext$method$_init$2d7e37acd2b65ac2(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_javax_security_auth_Subject$object *_jc_javax_security_auth_login_LoginContext$method$getSubject$7db516660a3ff3c7(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *);
extern void _jc_javax_security_auth_login_LoginContext$method$login$0b42121bc1e69d10(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *);
extern void _jc_javax_security_auth_login_LoginContext$method$logout$02724cf61fcc2a54(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *);
extern struct _jc_object *_jc_javax_security_auth_login_LoginContext$method$lookupModule$672a812592436c94(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *, struct _jc_javax_security_auth_Subject$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_login_LoginContext$method_info$getSubject$7db516660a3ff3c7;
extern _jc_method _jc_javax_security_auth_login_LoginContext$method_info$login$0b42121bc1e69d10;
extern _jc_method _jc_javax_security_auth_login_LoginContext$method_info$logout$02724cf61fcc2a54;
extern _jc_method _jc_javax_security_auth_login_LoginContext$method_info$lookupModule$672a812592436c94;

// Static methods
extern struct _jc_object *_jc_javax_security_auth_login_LoginContext$method$defaultHandler$8e5865a39fdf1f5e(_jc_env *);

// Virtual methods structure
struct _jc_javax_security_auth_login_LoginContext$vmethods {
	struct _jc_javax_security_auth_Subject$object	*(*getSubject$7db516660a3ff3c7)(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *);
	void	(*login$0b42121bc1e69d10)(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *);
	void	(*logout$02724cf61fcc2a54)(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *);
	struct _jc_object	*(*lookupModule$672a812592436c94)(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *, struct _jc_javax_security_auth_Subject$object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_security_auth_login_LoginContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_login_LoginContext$vmethods	javax_security_auth_login_LoginContext;
};

// Vtype
struct _jc_javax_security_auth_login_LoginContext$vtype {
	_jc_type			type;
	_jc_javax_security_auth_login_LoginContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_login_LoginContext$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_object	*cbHandler;
	struct _jc_javax_security_auth_Subject$object	*subject;
	_jc_object_array	*entries;
	_jc_object_array	*modules;
	struct _jc_object	*sharedState;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_login_LoginContext$refs {
    _jc_javax_security_auth_login_LoginContext$sub_refs	javax_security_auth_login_LoginContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_login_LoginContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_login_LoginContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_login_LoginContext$sub_nonrefs	javax_security_auth_login_LoginContext;
};

// Object instance structure
struct _jc_javax_security_auth_login_LoginContext$object {
	_jc_javax_security_auth_login_LoginContext$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_login_LoginContext$vtype	*vtype;
	_jc_javax_security_auth_login_LoginContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_login_LoginContext$vtype _jc_javax_security_auth_login_LoginContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_login_LoginContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_login_LoginContext$class_object;

#endif	/* _JC_javax_security_auth_login_LoginContext_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/login/LoginContext.h <==
// public class javax.security.auth.login.LoginContext

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6fe934cf02ea1e8d javax_security_auth_login_LoginContext

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_login_LoginContext_H_
#define _JC_javax_security_auth_login_LoginContext_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_javax_security_auth_Subject$object;
struct _jc_javax_security_auth_callback_CallbackHandler$object;
struct _jc_javax_security_auth_login_AppConfigurationEntry$object;
struct _jc_javax_security_auth_spi_LoginModule$object;

// Typedefs
typedef struct _jc_javax_security_auth_login_LoginContext$sub_refs	_jc_javax_security_auth_login_LoginContext$sub_refs;
typedef struct _jc_javax_security_auth_login_LoginContext$sub_nonrefs	_jc_javax_security_auth_login_LoginContext$sub_nonrefs;
typedef struct _jc_javax_security_auth_login_LoginContext$refs	_jc_javax_security_auth_login_LoginContext$refs;
typedef struct _jc_javax_security_auth_login_LoginContext$nonrefs	_jc_javax_security_auth_login_LoginContext$nonrefs;
typedef struct _jc_javax_security_auth_login_LoginContext$object	_jc_javax_security_auth_login_LoginContext$object;

typedef struct _jc_javax_security_auth_login_LoginContext$fields_struct	_jc_javax_security_auth_login_LoginContext$fields_struct;
typedef const struct _jc_javax_security_auth_login_LoginContext$vmethods	_jc_javax_security_auth_login_LoginContext$vmethods;
typedef const struct _jc_javax_security_auth_login_LoginContext$vtable	_jc_javax_security_auth_login_LoginContext$vtable;
typedef const struct _jc_javax_security_auth_login_LoginContext$vtype	_jc_javax_security_auth_login_LoginContext$vtype;

// Class fields structure
struct _jc_javax_security_auth_login_LoginContext$fields_struct {
	struct _jc_java_lang_String$object	*OTHER;
};
extern _jc_javax_security_auth_login_LoginContext$fields_struct _jc_javax_security_auth_login_LoginContext$class_fields;

// Constructors
extern void _jc_javax_security_auth_login_LoginContext$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_login_LoginContext$method$_init$95c94ca4add8ad7a(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *, struct _jc_java_lang_String$object *, struct _jc_javax_security_auth_Subject$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_login_LoginContext$method$_init$3e91c4d32da7a4da(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *, struct _jc_java_lang_String$object *, struct _jc_javax_security_auth_Subject$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_login_LoginContext$method$_init$2d7e37acd2b65ac2(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_security_auth_Subject$object *_jc_javax_security_auth_login_LoginContext$method$getSubject$7db516660a3ff3c7(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_login_LoginContext$method$login$0b42121bc1e69d10(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_login_LoginContext$method$logout$02724cf61fcc2a54(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_security_auth_login_LoginContext$method$lookupModule$672a812592436c94(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *, struct _jc_javax_security_auth_Subject$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_login_LoginContext$method_info$getSubject$7db516660a3ff3c7;
extern _jc_method _jc_javax_security_auth_login_LoginContext$method_info$login$0b42121bc1e69d10;
extern _jc_method _jc_javax_security_auth_login_LoginContext$method_info$logout$02724cf61fcc2a54;
extern _jc_method _jc_javax_security_auth_login_LoginContext$method_info$lookupModule$672a812592436c94;

// Static methods
extern struct _jc_object *_jc_javax_security_auth_login_LoginContext$method$defaultHandler$8e5865a39fdf1f5e(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_security_auth_login_LoginContext$vmethods {
	struct _jc_javax_security_auth_Subject$object	*(*getSubject$7db516660a3ff3c7)(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *) _JC_JCNI_ATTR;
	void	(*login$0b42121bc1e69d10)(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *) _JC_JCNI_ATTR;
	void	(*logout$02724cf61fcc2a54)(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*lookupModule$672a812592436c94)(_jc_env *, struct _jc_javax_security_auth_login_LoginContext$object *, struct _jc_javax_security_auth_login_AppConfigurationEntry$object *, struct _jc_javax_security_auth_Subject$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_auth_login_LoginContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_login_LoginContext$vmethods	javax_security_auth_login_LoginContext;
};

// Vtype
struct _jc_javax_security_auth_login_LoginContext$vtype {
	_jc_type			type;
	_jc_javax_security_auth_login_LoginContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_login_LoginContext$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_object	*cbHandler;
	struct _jc_javax_security_auth_Subject$object	*subject;
	_jc_object_array	*entries;
	_jc_object_array	*modules;
	struct _jc_object	*sharedState;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_login_LoginContext$refs {
    _jc_javax_security_auth_login_LoginContext$sub_refs	javax_security_auth_login_LoginContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_login_LoginContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_login_LoginContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_login_LoginContext$sub_nonrefs	javax_security_auth_login_LoginContext;
};

// Object instance structure
struct _jc_javax_security_auth_login_LoginContext$object {
	_jc_javax_security_auth_login_LoginContext$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_login_LoginContext$vtype	*vtype;
	_jc_javax_security_auth_login_LoginContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_login_LoginContext$vtype _jc_javax_security_auth_login_LoginContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_login_LoginContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_login_LoginContext$class_object;

#endif	/* _JC_javax_security_auth_login_LoginContext_H_ */
